@@ -20,11 +20,11 @@
 using System;
 using System.Collections.Generic;
 using System.ComponentModel;
+using System.Diagnostics;
 using System.Drawing;
 using System.Text;
-using System.Windows.Forms;
 using System.Threading;
-using System.Diagnostics;
+using System.Windows.Forms;
 
 using KeePass.App;
 using KeePass.App.Configuration;
@@ -58,7 +58,7 @@ namespace KeePass.Forms
 			BannerFactory.CreateBannerEx(this, m_bannerImage,
 				Properties.Resources.B48x48_View_Detailed,
 				KPRes.ConfigureColumns, KPRes.ConfigureColumnsDesc);
-			this.Icon = Properties.Resources.KeePass;
+			this.Icon = AppIcons.Default;
 			this.Text = KPRes.ConfigureColumns;
 
 			float fWidth = (float)(m_lvColumns.ClientRectangle.Width -
@@ -224,6 +224,7 @@ namespace KeePass.Forms
 			AddStdAceColumn(l, AceColumnType.OverrideUrl);
 			AddStdAceColumn(l, AceColumnType.Tags);
 			AddStdAceColumn(l, AceColumnType.ExpiryTimeDateOnly);
+			AddStdAceColumn(l, AceColumnType.LastPasswordModTime);
 
 			d.Clear();
 			// Add active plugin columns (including those of uninstalled plugins)
