@@ -20,13 +20,14 @@
 using System;
 using System.Collections.Generic;
 using System.ComponentModel;
+using System.Diagnostics;
 using System.Drawing;
 using System.Text;
 using System.Windows.Forms;
 
 using KeePass.App;
-using KeePass.UI;
 using KeePass.Resources;
+using KeePass.UI;
 
 namespace KeePass.Forms
 {
@@ -47,13 +48,14 @@ namespace KeePass.Forms
 			BannerFactory.CreateBannerEx(this, m_bannerImage,
 				Properties.Resources.B48x48_Folder_Download, KPRes.HelpSourceSelection,
 				KPRes.HelpSourceSelectionDesc);
-			this.Icon = Properties.Resources.KeePass;
+			this.Icon = AppIcons.Default;
 			this.Text = KPRes.HelpSourceSelection;
 
 			FontUtil.AssignDefaultBold(m_radioLocal);
 			FontUtil.AssignDefaultBold(m_radioOnline);
 
-			if(AppHelp.LocalHelpAvailable == false)
+			Debug.Assert(!m_lblLocal.AutoSize); // For RTL support
+			if(!AppHelp.LocalHelpAvailable)
 			{
 				m_radioLocal.Enabled = false;
 				m_lblLocal.Text = KPRes.HelpSourceNoLocalOption;
