@@ -51,21 +51,21 @@ namespace KeePass.Plugins
 		{
 			if(plgxOutInfo == null) throw new ArgumentNullException("plgxOutInfo");
 
-			string[] vCsproj = UrlUtil.GetFilePaths(strDirPath, "*.csproj",
-				SearchOption.AllDirectories).ToArray();
-			if(vCsproj.Length == 1)
+			List<string> lCsproj = UrlUtil.GetFilePaths(strDirPath, "*.csproj",
+				SearchOption.AllDirectories);
+			if(lCsproj.Count == 1)
 			{
 				plgxOutInfo.ProjectType = PlgxProjectType.CSharp;
-				PlgxCsprojLoader.Load(vCsproj[0], plgxOutInfo);
+				PlgxCsprojLoader.Load(lCsproj[0], plgxOutInfo);
 				return;
 			}
 
-			// string[] vVbproj = UrlUtil.GetFilePaths(strDirPath, "*.vbproj",
-			//	SearchOption.AllDirectories).ToArray();
-			// if(vVbproj.Length == 1)
+			// List<string> lVbproj = UrlUtil.GetFilePaths(strDirPath, "*.vbproj",
+			//	SearchOption.AllDirectories);
+			// if(lVbproj.Count == 1)
 			// {
 			//	plgxOutInfo.ProjectType = PlgxProjectType.VisualBasic;
-			//	PlgxCsprojLoader.Load(vVbproj[0], plgxOutInfo);
+			//	PlgxCsprojLoader.Load(lVbproj[0], plgxOutInfo);
 			//	return;
 			// }
 
