@@ -104,6 +104,12 @@ namespace KeePass.UI.ToolStripRendering
 
 		protected override void OnRenderItemCheck(ToolStripItemImageRenderEventArgs e)
 		{
+			if(MonoWorkarounds.IsRequired())
+			{
+				base.OnRenderItemCheck(e);
+				return;
+			}
+
 			Image imgToDispose = null;
 			try
 			{
@@ -234,7 +240,7 @@ namespace KeePass.UI.ToolStripRendering
 				if(imgToDispose != null) imgToDispose.Dispose();
 			}
 
-			base.OnRenderItemCheck(e);
+			base.OnRenderItemCheck(e); // Not in 'finally', see 'eNew'
 		}
 
 		protected override void OnRenderItemText(ToolStripItemTextRenderEventArgs e)
