@@ -599,8 +599,8 @@ namespace KeePass.Util
 				else
 				{
 					string strMain = strHdr + MessageService.NewParagraph + strSub;
-					iResult = (MessageService.AskYesNo(strMain + MessageService.NewParagraph +
-						KPRes.UpdateCheckEnableQ, PwDefs.ShortProductName) ?
+					iResult = (MessageService.AskYesNo(strMain +
+						MessageService.NewParagraph + KPRes.UpdateCheckEnableQ) ?
 						(int)DialogResult.Yes : (int)DialogResult.No);
 				}
 
